/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsrootidl.idl"

%{C++
#define NS_IMIMEHEADERS_CONTRACTID \
  "@mozilla.org/messenger/mimeheaders;1"
// {9C4DA772-07EB-11d3-8EE5-00A024669799}
#define NS_IMIMEHEADERS_CID \
    { 0x13e16677, 0x6648, 0x11d3, \
    { 0xa7, 0x2f, 0x0, 0x60, 0xb0, 0xeb, 0x39, 0xb5 } }
%}

/* 
 * nsIMimeHeaders Interface declaration 
 */ 
[scriptable, uuid(13E16676-6648-11d3-A72F-0060B0EB39B5)]
interface nsIMimeHeaders : nsISupports {
  void initialize([const] in string allHeaders, in long allHeadersSize);
  string extractHeader ([const] in string headerName, in boolean getAllOfThem);
  readonly attribute string allHeaders;
};

%{C++
nsresult NS_NewMimeHeaders(const nsIID &aIID, void ** aInstancePtrResult);
%}
